@@ -114,12 +114,12 @@ class NoticeManager(models.Manager):
             qs = qs.filter(on_site=on_site)
         return qs
 
-    def unseen_count_for(self, user):
+    def unseen_count_for(self, user, **kwargs):
         """
         returns the number of unseen notices for the given user but does not
         mark them seen
         """
-        return self.filter(user=user, unseen=True).count()
+        return self.notices_for(user, unseen=True, **kwargs).count()
 
 class Notice(models.Model):
 
@@ -381,9 +381,17 @@ class ObservedItem(models.Model):
         verbose_name = _('observed item')
         verbose_name_plural = _('observed items')
 
-    def send_notice(self):
-        send([self.user], self.notice_type.label,
-             {'observed': self.observed_object})
+    def send_notice(self, extra_context=None):
+
+        if extra_context is None:
+            extra_context = {}
+
+        context = {
+            "observed": self.observed_object,
+        }
+        context.update(extra_context)
+
+        send([self.user], self.notice_type.label, context)
 
 
 def observe(observed, observer, notice_type_label, signal='post_save'):
@@ -405,13 +413,13 @@ def stop_observing(observed, observer, signal='post_save'):
     observed_item = ObservedItem.objects.get_for(observed, observer, signal)
     observed_item.delete()
 
-def send_observation_notices_for(observed, signal='post_save'):
+def send_observation_notices_for(observed, signal='post_save', extra_context=None):
     """
     Send a notice for each registered user about an observed object.
     """
     observed_items = ObservedItem.objects.all_for(observed, signal)
     for observed_item in observed_items:
-        observed_item.send_notice()
+        observed_item.send_notice(extra_context)
     return observed_items
 
 def is_observing(observed, observer, signal='post_save'):
